=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2011-03-10 16:03:37 +0000
+++ bzrlib/bzrdir.py	2011-03-10 16:11:31 +0000
@@ -59,7 +59,6 @@
     xml5,
     )
 from bzrlib.repofmt import pack_repo
-from bzrlib.smart.client import _SmartClient
 from bzrlib.store.versioned import VersionedFileStore
 from bzrlib.transactions import WriteTransaction
 from bzrlib.transport import (
@@ -1499,9 +1498,10 @@
         except KeyError:
             raise errors.UnknownFormatError(format=format_string, kind='bzrdir')
 
-    def known_formats(self):
+    @classmethod
+    def known_formats(cls):
         result = set()
-        for name, format in self.formats.iteritems():
+        for name, format in cls.formats.iteritems():
             result.add(format)
         return result
 
@@ -1537,7 +1537,8 @@
             from bzrlib.remote import RemoteBzrDirFormat
             return RemoteBzrDirFormat()
 
-    def known_formats(self):
+    @classmethod
+    def known_formats(cls):
         from bzrlib.remote import RemoteBzrDirFormat
         return set([RemoteBzrDirFormat()])
 
@@ -1559,7 +1560,8 @@
     # _lock_class must be set in subclasses to the lock type, typ.
     # TransportLock or LockDir
 
-    def get_format_string(self):
+    @classmethod
+    def get_format_string(cls):
         """Return the ASCII format string that identifies this format."""
         raise NotImplementedError(self.get_format_string)
 
@@ -1621,6 +1623,7 @@
             except errors.NoSmartMedium:
                 pass
             else:
+                from bzrlib.remote import RemoteBzrDirFormat
                 # TODO: lookup the local format from a server hint.
                 remote_dir_format = RemoteBzrDirFormat()
                 remote_dir_format._network_name = self.network_name()
@@ -1741,12 +1744,6 @@
         """
         raise NotImplementedError(self._open)
 
-    @classmethod
-    def register_format(klass, format):
-        """Register a new BzrDir format.
-        """
-        BzrProber.formats.register(format.get_format_string(), format)
-
     def _supply_sub_formats_to(self, other_format):
         """Give other_format the same values for sub formats as this has.
 
@@ -1759,10 +1756,6 @@
         :return: None.
         """
 
-    @classmethod
-    def unregister_format(klass, format):
-        BzrProber.formats.remove(format.get_format_string())
-
 
 class BzrDirFormat4(BzrDirFormat):
     """Bzr dir format 4.
@@ -1781,7 +1774,8 @@
 
     fixed_components = True
 
-    def get_format_string(self):
+    @classmethod
+    def get_format_string(cls):
         """See BzrDirFormat.get_format_string()."""
         return "Bazaar-NG branch, format 0.0.4\n"
 
@@ -1861,7 +1855,8 @@
 
     _lock_class = lockable_files.TransportLock
 
-    def get_format_string(self):
+    @classmethod
+    def get_format_string(cls):
         """See BzrDirFormat.get_format_string()."""
         return "Bazaar-NG branch, format 5\n"
 
@@ -1922,7 +1917,8 @@
 
     _lock_class = lockable_files.TransportLock
 
-    def get_format_string(self):
+    @classmethod
+    def get_format_string(cls):
         """See BzrDirFormat.get_format_string()."""
         return "Bazaar-NG branch, format 6\n"
 
@@ -2114,7 +2110,8 @@
             raise NotImplementedError(self.get_converter)
         return ConvertMetaToMeta(format)
 
-    def get_format_string(self):
+    @classmethod
+    def get_format_string(cls):
         """See BzrDirFormat.get_format_string()."""
         return "Bazaar-NG meta directory, format 1\n"
 
@@ -2182,11 +2179,11 @@
 
 
 # Register bzr formats
-BzrDirFormat.register_format(BzrDirFormat4())
-BzrDirFormat.register_format(BzrDirFormat5())
-BzrDirFormat.register_format(BzrDirFormat6())
+BzrProber.formats.register(BzrDirFormat4.get_format_string(), BzrDirFormat4())
+BzrProber.formats.register(BzrDirFormat5.get_format_string(), BzrDirFormat5())
+BzrProber.formats.register(BzrDirFormat6.get_format_string(), BzrDirFormat6())
 __default_format = BzrDirMetaFormat1()
-BzrDirFormat.register_format(__default_format)
+BzrProber.formats.register(__default_format.get_format_string(), __default_format)
 controldir.ControlDirFormat._default_format = __default_format
 
 

=== modified file 'bzrlib/controldir.py'
--- bzrlib/controldir.py	2011-03-10 16:03:37 +0000
+++ bzrlib/controldir.py	2011-03-10 16:11:31 +0000
@@ -799,8 +799,8 @@
         """Return all the known formats.
         """
         result = set()
-        for prober in klass._probers + klass._server_probers:
-            result.update(prober.known_formats())
+        for prober_kls in klass._probers + klass._server_probers:
+            result.update(prober_kls.known_formats())
         return result
 
     @classmethod
@@ -915,12 +915,13 @@
         """
         raise NotImplementedError(self.probe_transport)
 
-    def known_formats(self):
+    @classmethod
+    def known_formats(cls):
         """Return the control dir formats known by this prober.
 
         :return: A set of known formats.
         """
-        raise NotImplementedError(self.known_formats)
+        raise NotImplementedError(cls.known_formats)
 
 
 class ControlDirFormatInfo(object):

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2011-03-10 16:00:38 +0000
+++ bzrlib/remote.py	2011-03-10 16:11:31 +0000
@@ -41,6 +41,7 @@
     )
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.smart import client, vfs, repository as smart_repo
+from bzrlib.smart.client import _SmartClient
 from bzrlib.revision import NULL_REVISION
 from bzrlib.repository import RepositoryWriteLockResult
 from bzrlib.trace import mutter, note, warning

=== modified file 'bzrlib/tests/per_controldir/test_controldir.py'
--- bzrlib/tests/per_controldir/test_controldir.py	2011-03-08 00:53:45 +0000
+++ bzrlib/tests/per_controldir/test_controldir.py	2011-03-10 16:11:31 +0000
@@ -26,7 +26,6 @@
     errors,
     gpg,
     osutils,
-    repository,
     transport,
     ui,
     urlutils,
@@ -46,6 +45,7 @@
     )
 from bzrlib.remote import (
     RemoteBzrDir,
+    RemoteBzrDirFormat,
     RemoteRepository,
     )
 
@@ -1068,7 +1068,7 @@
         self.assertIsInstance(control, controldir.ControlDir)
         opened = bzrdir.BzrDir.open(t.base)
         expected_format = self.bzrdir_format
-        if isinstance(expected_format, bzrdir.RemoteBzrDirFormat):
+        if isinstance(expected_format, RemoteBzrDirFormat):
             # Current RemoteBzrDirFormat's do not reliably get network_name
             # set, so we skip a number of tests for RemoteBzrDirFormat's.
             self.assertIsInstance(control, RemoteBzrDir)
@@ -1093,7 +1093,7 @@
         # key in the registry gives back the same format. For remote obects
         # we check that the network_name of the RemoteBzrDirFormat we have
         # locally matches the actual format present on disk.
-        if isinstance(format, bzrdir.RemoteBzrDirFormat):
+        if isinstance(format, RemoteBzrDirFormat):
             dir._ensure_real()
             real_dir = dir._real_bzrdir
             network_name = format.network_name()

=== modified file 'bzrlib/tests/test_controldir.py'
--- bzrlib/tests/test_controldir.py	2011-03-10 16:03:37 +0000
+++ bzrlib/tests/test_controldir.py	2011-03-10 16:11:31 +0000
@@ -131,7 +131,7 @@
             self.prober.probe_transport, transport)
 
     def test_known_formats(self):
-        known_formats = self.prober.known_formats()
+        known_formats = self.prober_cls.known_formats()
         self.assertIsInstance(known_formats, set)
         for format in known_formats:
             self.assertIsInstance(format, controldir.ControlDirFormat,

=== modified file 'bzrlib/tests/test_import_tariff.py'
--- bzrlib/tests/test_import_tariff.py	2011-03-04 22:50:20 +0000
+++ bzrlib/tests/test_import_tariff.py	2011-03-10 16:11:31 +0000
@@ -110,6 +110,7 @@
             'bzrlib.remote',
             'bzrlib.sign_my_commits',
             'bzrlib.smart',
+            'bzrlib.smart.client',
             'bzrlib.transform',
             'bzrlib.version_info_formats.format_rio',
             'bzrlib.workingtree_2',

